@@ -14,6 +14,16 @@ def get_package_version(file_path):
         return data['version']
 
 
+def run_sentry():
+    import sentry_sdk
+    from sentry_sdk.integrations.django import DjangoIntegration
+    sentry_sdk.init(
+        dsn="https://677252655469434897723bab86b18ef0@o419846.ingest.sentry.io/5336964",
+        integrations=[DjangoIntegration()],
+        send_default_pii=True
+    )
+
+
 ALLOWED_HOSTS_DEV = [
     '127.0.0.1',
     'localhost',
@@ -53,6 +63,8 @@ INSTALLED_APPS = [
     "django.contrib.sitemaps",
 
     'django_user_agents',
+    'rosetta',
+
 ]
 
 MIDDLEWARE = [
@@ -208,5 +220,10 @@ LOGGING = {
             'propagate': True,
             'handlers': ['console'],
         },
+        'api': {
+            'level': 'DEBUG',
+            'propagate': True,
+            'handlers': ['console'],
+        },
     }
-}
+}
\ No newline at end of file
