@@ -2,8 +2,10 @@ from django.db import models
 from django.conf import settings
 from django.template.response import TemplateResponse
 from django.http import HttpResponse
+from django.utils import translation
 
 from webspace.cms.amp.utils import amp_mode_active
+from webspace.loader import get_model
 
 
 class BuildableModel(models.Model):
@@ -54,6 +56,7 @@ class WagtailPageBakeryModel(BuildableModel):
         #  Remove settings.DEBUG if you want to test static page
 
         if settings.DEBUG or request.is_preview or is_building:
+            self.active_language(request)
             return TemplateResponse(
                 request,
                 self.get_template(request, *args, **kwargs),
@@ -73,5 +76,11 @@ class WagtailPageBakeryModel(BuildableModel):
                 response['Content-Length'] = str(len(compressed))
                 return response
 
+    def active_language(self, request):
+        WebspaceSettings = get_model('cms', 'WebspaceSettings')
+        ws_settings = WebspaceSettings.for_site(request.site)
+        if ws_settings.language:
+            translation.activate(ws_settings.language)
+
     class Meta:
         abstract = True
