@@ -7,7 +7,8 @@ from webspace.cms.blocks.common import \
     TextBlock, \
     ButtonBlock, \
     EntryBlock, \
-    ImageWithSizeBlock
+    ImageWithSizeBlock, \
+    PersonBlock
 
 
 class CustomCard(blocks.StructBlock):
@@ -28,6 +29,10 @@ class CustomCard(blocks.StructBlock):
         label = "Custom Card"
 
 
+class PersonCard(PersonBlock):
+    pass
+
+
 class CardsEntry(EntryBlock):
     amp_scripts = ['carousel']
     theme_reverse = ThemeChoiceBlock(required=False)
@@ -35,6 +40,7 @@ class CardsEntry(EntryBlock):
     cards = blocks.StreamBlock(
         [
             ('custom', CustomCard()),
+            ('person', PersonCard())
         ],
         min_num=1
     )
