@@ -1,3 +1,7 @@
+STUDIO_NAME = 'Station Spatiale'
+STUDIO_URL = 'https://stationspatiale.com/'
+STUDIO_EMAIL = "hello@stationspatiale.com"
+
 BLOCK_TEMPLATES_PATH = 'cms/blocks'
 PAGES_TEMPLATES_PATH = 'cms/pages'
 ADMIN_TEMPLATES_PATH = 'cms/admin'
@@ -6,11 +10,10 @@ THEME_SPACE = 'space'
 THEME_SPACE_INVERSE = 'space-inverse'
 THEME_LIGHT = 'light'
 
-
 THEME_CHOICES = (
-    (THEME_SPACE, "Dark"),
-    (THEME_SPACE_INVERSE, "Dark Inverse"),
-    (THEME_LIGHT, "Light"),
+    (THEME_SPACE, "Primary"),
+    (THEME_SPACE_INVERSE, "Primary Inverse"),
+    (THEME_LIGHT, "Secondary"),
 )
 
 SIZE_XS = 'xs'
@@ -21,7 +24,6 @@ SIZE_X = 'x'
 SIZE_XL = 'xl'
 SIZE_FULL = 'full'
 
-
 SIZE_CHOICES = (
     (SIZE_XS, 'XS'),
     (SIZE_S, 'S'),
@@ -32,7 +34,6 @@ SIZE_CHOICES = (
     (SIZE_FULL, 'Full'),
 )
 
-
 CONTAINER_REGULAR = 'regular'
 CONTAINER_CONTENT = 'content'
 CONTAINER_FULL = 'full'
@@ -86,3 +87,18 @@ BACKROUND_POSITION_CHOICES = (
     (BACKROUND_POSITION_LEFT, "Left"),
     (BACKROUND_POSITION_RIGHT, "Right"),
 )
+
+LANGUAGE_FR = 'fr'
+LANGUAGE_EN = 'en'
+LANGUAGE_DE = 'de'
+LANGUAGE_NL = 'nl'
+LANGUAGE_ES = 'es'
+LANGUAGE_IT = 'it'
+LANGUAGES = [
+    (LANGUAGE_FR, 'French'),
+    (LANGUAGE_EN, 'English'),
+]
+LOCALES = {
+    LANGUAGE_FR: 'fr-FR',
+    LANGUAGE_EN: 'en-EN',
+}
