@@ -112,6 +112,8 @@ class AGenericPage(Page):
         verbose_name="Navigation",
     )
 
+    amp_active = models.BooleanField(default=True)
+
     body = StreamField([
         ('svg', SvgEntry()),
         ('image', ImageEntry()),
@@ -152,6 +154,7 @@ class AGenericPage(Page):
         FieldPanel('title'),
         FieldPanel('slug'),
         FieldPanel('theme'),
+        FieldPanel('amp_active'),
         SnippetChooserPanel('navigation'),
         InlinePanel("language_pages", label="Pages multi-language")
     ]
