@@ -69,9 +69,19 @@ class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
     tags = ClusterTaggableManager(through='BlogPageTag', blank=True)
     date = models.DateTimeField("Date publication + tri", default=date.today)
     date_updated = models.DateTimeField("Date mise à jour", default=None, null=True, blank=True)
-    intro = models.CharField(default='', max_length=500, blank=True)
-    intro_page = fields.RichTextField(default='', blank=True, features=settings.RICH_TEXT_FEATURES)
-    h1 = models.CharField(default='', max_length=200, blank=True)
+    intro = models.CharField(
+        default='',
+        max_length=500,
+        blank=True,
+        help_text="Texte d'introduction qui s'affiche sur un block article de présentation"
+    )
+    intro_page = fields.RichTextField(
+        default='',
+        blank=True,
+        features=settings.RICH_TEXT_FEATURES,
+        help_text="Texte qui s'affiche sur un la page de l'article"
+    )
+    h1 = models.CharField('Titre intro', default='', max_length=200, blank=True)
     related_blogs = StreamField([
         ('article', blocks.PageChooserBlock(required=False, target_model='cms.BlogPage')),
     ], blank=True)
@@ -87,8 +97,8 @@ class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
                          FieldPanel('date'),
                          FieldPanel('date_updated'),
                          FieldPanel('tags'),
-                         FieldPanel('intro'),
                          FieldPanel('h1'),
+                         FieldPanel('intro'),
                          FieldPanel('intro_page'),
                          StreamFieldPanel('related_blogs'),
                      ] + GenericPage.content_panels
@@ -138,11 +148,13 @@ class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
                             'link': node.attrib.get('id'),
                             'h4': []
                         })
+                    """
                     if node.tag == 'h4':
                         summary[-1]['h3'][-1]['h4'].append({
                             'content': node.text,
                             'link': node.attrib.get('id'),
                         })
+                    """
             context['summary'] = summary
         except Exception:
             context['summary'] = None
@@ -223,6 +235,7 @@ class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
         is_building = request.GET.get('build', False)
         request.is_preview = getattr(request, 'is_preview', False)
         if settings.DEBUG or request.is_preview or is_building:
+            self.active_language(request)
             return TemplateResponse(
                 request,
                 self.get_template(request),
